@@ -4,9 +4,21 @@ from django.db import models
 from django.contrib.auth.models import Group
 from django.utils.translation import ugettext_lazy as _
 from django.conf import settings
-from django.contrib.auth import get_user_model
+from django.core.exceptions import AppRegistryNotReady
+
+try:
+    # Django 1.7 way for importing custom user
+    from django.contrib.auth import AUTH_USER_MODEL
+    User = get_user_model()
+except ImportError:
+    try:
+        # Django 1.6 way for importing custom user, will crash in Django 1.7
+        from django.contrib.auth import get_user_model
+        User = get_user_model()
+    except AppRegistryNotReady:
+        # If all else fails, import default user model -- please report this bug
+        from django.contrib.auth.models import User
 
-User = get_user_model()
 
 class Restaurant(models.Model):
     restaurant_name = models.CharField(_('name'), max_length=50)
@@ -18,6 +30,10 @@ class Restaurant(models.Model):
     def __unicode__(self):
         return self.restaurant_name
 
+    def __str__(self):
+        return self.__unicode__()
+
+
 class Order(models.Model):
     date = models.DateField(_('date'))
     restaurant = models.ForeignKey(Restaurant)
@@ -26,7 +42,7 @@ class Order(models.Model):
 
     def get_total_sum(self):
         s = self.orderline_set.aggregate(models.Sum('price'))['price__sum']
-        if s == None:
+        if s is None:
             s = 0
         return s + self.extra_costs
 
@@ -64,9 +80,13 @@ class Order(models.Model):
     def __unicode__(self):
         return "%s @ %s" % (self.date.strftime("%d-%m-%Y"), self.restaurant)
 
+    def __str__(self):
+        return self.__unicode__()
+
     class Meta:
         get_latest_by = 'date'
 
+
 class OrderLine(models.Model):
     order = models.ForeignKey(Order)
     creator = models.ForeignKey(settings.AUTH_USER_MODEL, related_name=_('owner'))
@@ -94,15 +114,19 @@ class OrderLine(models.Model):
             return self.creator.username
         else:
             return self.creator.nickname
+    
+    def __str__(self):
+        return self.__unicode__()
 
     @models.permalink
     def get_absolute_url(self):
-        return ('edit', (), {'orderline_id' : self.id})
+        return ('edit', (), {'orderline_id': self.id})
 
     class Meta:
         verbose_name = _('Order line')
         verbose_name_plural = _('Order lines')
 
+
 class Transaction(models.Model):
     user = models.ForeignKey(settings.AUTH_USER_MODEL)
     amount = models.FloatField(_('amount'), default=0)
@@ -111,11 +135,15 @@ class Transaction(models.Model):
     def __unicode__(self):
         return self.user.get_username()
 
+    def __str__(self):
+        return self.__unicode__()
+
+
 class Balance(models.Model):
     user = models.OneToOneField(settings.AUTH_USER_MODEL)
 
     def get_balance(self):
-        if self.user.transaction_set.aggregate(models.Sum('amount'))['amount__sum'] == None:
+        if self.user.transaction_set.aggregate(models.Sum('amount'))['amount__sum'] is None:
             self.add_transaction(0)
         return self.user.transaction_set.aggregate(models.Sum('amount'))['amount__sum']
 
@@ -128,24 +156,31 @@ class Balance(models.Model):
 
     def deposit(self, amount):
         return self.add_transaction(amount)
-        #print('Deprecated notice, please add new transaction objects rather than calling the Balance object')
+        # print('Deprecated notice, please add new transaction objects rather than calling the Balance object')
 
     def withdraw(self, amount):
         return self.add_transaction(amount * -1)
-        #print('Deprecated notice, please add new transaction objects rather than calling the Balance object')
+        # print('Deprecated notice, please add new transaction objects rather than calling the Balance object')
 
     def __unicode__(self):
         return "%s: %s" % (self.user, self.get_balance())
 
+    def __str__(self):
+        return self.__unicode__()
+
+
 class ManageBalance(models.Model):
     user = models.ForeignKey(Balance)
     amount = models.FloatField(_('amount'), default=0)
 
+
 class ManageOrders(models.Model):
     orders = models.OneToOneField(Order, related_name=_('Orders'))
 
+
 class ManageUsers(models.Model):
     users = models.ManyToManyField(settings.AUTH_USER_MODEL, related_name=_('Users'))
 
+
 class ManageOrderLimit(models.Model):
     order_limit = models.IntegerField(_('Order limit'), default=100)
